%global varlibdir       %{_localstatedir}/lib/%{name}
%global checkdir        %{_localstatedir}/spool/%{name}
%global cmddir          %{varlibdir}/cmd
%global logdir          %{_localstatedir}/log/%{name}
%global tmpdir          %{varlibdir}/tmp
%global lockfile        %{_localstatedir}/run/%{name}/%{name}.pid

%global apacheconfdir  %{_sysconfdir}/httpd/conf.d
%global apacheuser      apache
%global apachegroup     apache

Name:           icinga
Version:        1.6.1
Release:        7%{?dist}
Summary:        Open Source host, service and network monitoring program

Group:          Applications/System
License:        GPLv2
URL:            http://www.icinga.org/
Source0:        http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.gz
Patch0:         icinga-1.5.1-paths.patch
Patch1:         icinga-1.6.1-init-cleanups.patch
# https://dev.icinga.org/issues/2235
Patch2:         0001-Fix-notification-template-installation-2235.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  gd-devel > 1.8
BuildRequires:  httpd
BuildRequires:  zlib-devel
BuildRequires:  libpng-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libdbi-devel
BuildRequires:  perl(ExtUtils::Embed)

Requires(pre):  shadow-utils
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts

%description
Icinga is an application, system and network monitoring application.
It can escalate problems by email, pager or any other medium. It is
also useful for incident or SLA reporting.

Icinga is written in C and is designed as a background process,
intermittently running checks on various services that you specify.

The actual service checks are performed by separate "plugin" programs
which return the status of the checks to Icinga.

Icinga is a fork of the nagios project.


%package doc
Summary: documentation %{name}
Group: Documentation
Requires: %{name} = %{version}-%{release}
 
%description doc
Documentation for %{name}


%package devel
Group: Applications/System
Summary: Development files for %{name}
Requires: %{name} = %{version}-%{release}

%description devel
Provides include files that %{name}-related applications may compile against.


%package gui
Summary: Web content for %{name}
Group: Applications/System
Requires: %{name} = %{version}-%{release}
Requires: %{name}-doc = %{version}-%{release}
Requires: httpd

%description gui
This package contains the webgui (html,css,cgi etc.) for %{name}

%package idoutils
Summary: database broker module for %{name}
Group: Applications/System
Requires: %{name} = %{version}-%{release}

%description idoutils
This package contains the idoutils broker module for %{name} which provides
database storage via libdbi.


%prep
%setup -q
%patch0 -p1 -b .paths
%patch1 -p1 -b .no-default-start
%patch2 -p1 -b .notification-template


%build
sed -i 's|^ \(package Embed::Persistent;\)$|\1|' p1.pl.in
sed -i 's|resource.cfg|private/resource.cfg|' sample-config/icinga.cfg.in
egrep -rl '/usr/local/icinga/var/rw' . | 
    xargs sed -i 's|/usr/local/icinga/var/rw|%{cmddir}|g'

%configure \
    --datadir="%{_datadir}/%{name}"         \
    --datarootdir="%{_datadir}/%{name}"     \
    --libexecdir="%{_libexecdir}/%{name}"   \
    --localstatedir="%{varlibdir}"          \
    --bindir="%{_sbindir}"                  \
    --sbindir="%{_libdir}/%{name}/cgi-bin"  \
    --sysconfdir="%{_sysconfdir}/%{name}"   \
    --with-cgiurl="/%{name}/cgi-bin"        \
    --with-checkresult-dir="%{checkdir}"    \
    --with-command-group="%{name}cmd"       \
    --with-command-user="%{name}"           \
    --with-ext-cmd-file-dir="%{cmddir}"     \
    --with-gd-inc="%{_includedir}"          \
    --with-gd-lib="%{_libdir}"              \
    --with-htmurl="/%{name}"                \
    --with-httpd-conf=%{apacheconfdir}      \
    --with-icinga-group="%{name}"           \
    --with-icinga-user="%{name}"            \
    --with-init-dir="%{_initrddir}"         \
    --with-lockfile="%{lockfile}"           \
    --with-mail="/bin/mail"                 \
    --with-web-user=%{apacheuser}           \
    --with-web-group=%{apachegroup}         \
    --enable-event-broker                   \
    --enable-embedded-perl                  \
    --enable-idoutils                       \
    --with-httpd-conf=%{apacheconfdir}      \
    --with-init-dir=%{_initrddir}           \
    --with-log-dir=%{logdir}                \
    --with-cgi-log-dir=%{logdir}/gui        \
    --with-p1-file-dir="%{_libdir}/%{name}"
make %{?_smp_mflags} all


%install
rm -rf %{buildroot}
mkdir -p %{buildroot}/%{apacheconfdir}
make \
    DESTDIR="%{buildroot}"  \
    INSTALL_OPTS="-p"       \
    INSTALL_OPTS_WEB=""     \
    COMMAND_OPTS=""         \
    INIT_OPTS=""            \
    install-unstripped      \
    install-commandmode     \
    install-config          \
    install-init            \
    install-webconf         \
    install-idoutils

# Overwrite the stock init script with the redhat-style init
install -Dp -m 755 daemon-init-redhat %{buildroot}%{_initrddir}/%{name}

# Install header-file
install -Dp -m 0644 include/locations.h %{buildroot}%{_includedir}/%{name}/locations.h

# Drop group write from %{_libexecdir}/%{name}
chmod 755 %{buildroot}%{_libexecdir}/%{name}

# Move resource.cfg to private dir
install -d -m 0750 %{buildroot}%{_sysconfdir}/%{name}/private
mv %{buildroot}%{_sysconfdir}/%{name}/resource.cfg %{buildroot}%{_sysconfdir}/%{name}/private/resource.cfg

# Create logdirs
install -d -m 755 %{buildroot}%{logdir}/archives

# Create rundir
install -d -m 755 %{buildroot}%{_localstatedir}/run/%{name}

# Create tmp dir
install -d -m 775 %{buildroot}%{tmpdir}

# Enable cmd.cgi logging by default
sed -i -e '
        s|use_logging.*|use_logging=1|;
        s|cgi_log_file.*|cgi_log_file=%{logdir}/gui/icinga-cgi.log|;
        s|cgi_log_archive_path=.*|cgi_log_archive_path=%{logdir}/gui|;
   ' %{buildroot}%{_sysconfdir}/icinga/cgi.cfg

# Move idoutils sample configs to final name
mv %{buildroot}%{_sysconfdir}/%{name}/ido2db.cfg-sample %{buildroot}%{_sysconfdir}/%{name}/ido2db.cfg
mv %{buildroot}%{_sysconfdir}/%{name}/idomod.cfg-sample %{buildroot}%{_sysconfdir}/%{name}/idomod.cfg
mv %{buildroot}%{_sysconfdir}/%{name}/modules/idoutils.cfg-sample %{buildroot}%{_sysconfdir}/%{name}/modules/idoutils.cfg

# Copy idutils db-script
cp -r module/idoutils/db %{buildroot}%{_sysconfdir}/%{name}/idoutils


%pre
# Add icinga user/group
getent group %{name} >/dev/null || groupadd -r %{name}
getent group %{name}cmd >/dev/null || groupadd -r %{name}cmd
getent passwd %{name} >/dev/null || \
    useradd -r -G %{name}cmd -g %{name} -d %{varlibdir} \
    -s /sbin/nologin -c "Network monitoring" %{name}
exit 0


%post
/sbin/chkconfig --add %{name}


%preun
if [ $1 -eq 0 ]; then
    /sbin/service %{name} stop &>/dev/null || :
    /sbin/chkconfig --del %{name}
fi


%postun
if [ $1 -ge 1 ] ; then
    /sbin/service %{name} condrestart &>/dev/null || :
fi


%pre gui
/usr/sbin/usermod -a -G %{name}cmd %{apacheuser}


%postun gui
if [ $1 -ge 1 ] ; then
    /sbin/service httpd condrestart &>/dev/null || :
fi


%post idoutils
/sbin/chkconfig --add ido2db


%preun idoutils
if [ $1 -eq 0 ]; then
    /sbin/service idoutils stop &>/dev/null || :
    /sbin/chkconfig --del ido2db
fi


%postun idoutils
if [ "$1" -ge "1" ] ; then
    /sbin/service idoutils condrestart &>/dev/null || :
fi


%clean
%{__rm} -rf %{buildroot}


%files
%defattr(-,root,root,-)
%{_initrddir}/%{name}
%attr(-,%{name},%{name}) %dir %{_sysconfdir}/%{name}
%attr(-,%{name},%{name}) %dir %{_sysconfdir}/%{name}/modules
%attr(-,%{name},%{name}) %dir %{_sysconfdir}/%{name}/objects
%exclude %{_sysconfdir}/%{name}/cgi*.cfg
%exclude %{_sysconfdir}/%{name}/ido*.cfg
%exclude %{_sysconfdir}/%{name}/objects/ido*.cfg
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/*.cfg
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/objects/*.cfg
%attr(0750,root,%{name}) %dir %{_sysconfdir}/%{name}/private
%attr(0640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/private/resource.cfg
%attr(0755,root,root) %{_sbindir}/%{name}
%attr(0755,root,root) %{_sbindir}/%{name}stats
%dir %{_libexecdir}/%{name}
%dir %{_libdir}/%{name}
%attr(0644,root,root) %{_libdir}/%{name}/p1.pl
%attr(-,%{name},%{name}) %dir %{checkdir}
%attr(-,%{name},%{name}) %dir %{varlibdir}
%attr(-,%{name},%{name}) %dir %{tmpdir}
%attr(-,%{name},%{name}) %dir %{logdir}
%attr(-,%{name},%{name}) %dir %{logdir}/archives
%attr(-,%{name},%{name}) %dir %{_localstatedir}/run/%{name}
%attr(2775,%{name},%{name}cmd) %dir %{cmddir}


%files devel
%defattr(-,root,root)
%{_includedir}/%{name}


%files doc
%defattr(-,root,root,-)
%{_datadir}/%{name}/docs


%files gui
%defattr(-,root,root,-)
%config(noreplace) %{apacheconfdir}/%{name}.conf
%dir %{_datadir}/%{name}
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/cgi*.cfg
%{_libdir}/%{name}/cgi-bin
%{_datadir}/%{name}/contexthelp
%{_datadir}/%{name}/images
%{_datadir}/%{name}/index.html
%{_datadir}/%{name}/js
%{_datadir}/%{name}/main.html
%{_datadir}/%{name}/media
%{_datadir}/%{name}/menu.html
%{_datadir}/%{name}/robots.txt
%{_datadir}/%{name}/sidebar.html
%{_datadir}/%{name}/ssi
%{_datadir}/%{name}/stylesheets
%attr(-,%{name},%{apachegroup}) %dir %{logdir}/gui
%attr(-,%{name},%{name}) %{logdir}/gui/*
# FIXME Drop this hidden file and control access via httpd conf file
%attr(-,%{name},%{name}) %{logdir}/gui/.htaccess


%files idoutils
%defattr(-,root,root,-)
%attr(755,root,root) %{_initrddir}/ido2db
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/ido2db.cfg
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/idomod.cfg
%config(noreplace) %{_sysconfdir}/icinga/modules/idoutils.cfg
%config(noreplace) %{_sysconfdir}/icinga/objects/ido2db_check_proc.cfg
%{_sysconfdir}/%{name}/idoutils
%{_sbindir}/ido2db
%{_sbindir}/log2ido
%{_sbindir}/idomod.o


%changelog
* Mon Jan 23 2012 Todd Zullinger <tmz@pobox.com> - 1.6.1-7
- Init script cleanups

* Fri Jan 20 2012 Todd Zullinger <tmz@pobox.com> - 1.6.1-6
- Revert %%{_libexecdir}/%%{name} symlink
- Fix license, it's just GPLv2, no "or later"

* Fri Jan 20 2012 Todd Zullinger <tmz@pobox.com> - 1.6.1-5
- Make %%{_libexecdir}/%%{name} a symlink to %%{_libdir}/nagios

* Tue Jan 17 2012 Todd Zullinger <tmz@pobox.com>
- Fix typo in %%{apachegroup} (missing 'e')

* Tue Jan 03 2012 Todd Zullinger <tmz@pobox.com> - 1.6.1-4
- Make doc subpackage require the same version/release as main package

* Tue Jan 03 2012 Todd Zullinger <tmz@pobox.com> - 1.6.1-3
- Exclude objects/ido*.cfg from main package
- Fix notification template installation (upstream #2235)

* Mon Jan 02 2012 Todd Zullinger <tmz@pobox.com> - 1.6.1-2
- Make gui log dir writable by apache group

* Mon Jan 02 2012 Todd Zullinger <tmz@pobox.com> - 1.6.1-1
- Update to 1.6.1
- changes from upstream:
  - Enable cmd.cgi logging
  - Drop api subpackage
  - Add --with-web-user/--with-web-group
  - Remove nagios from provides

* Sat Nov 12 2011 Todd Zullinger <tmz@pobox.com> - 1.5.1-1.1
- Add %%{_sysconfdir}/icinga/modules to main package
- Disable default start in initscript

* Tue Nov 08 2011 Todd Zullinger <tmz@pobox.com> - 1.5.1-1
- Update to 1.5.1

* Fri Mar 11 2011 Todd Zullinger <tmz@pobox.com> - 1.3.0-2.1
- Clean up BuildRequires
- Use root as default owner/group
- Add -devel package for header files
- Own %%{_sysconfdir}/%%{name}/objects
- Bring scriptlets in line with Fedora guidelines
- Use redhat-style initscript

* Tue Feb 15 2011 Cheistoph Maser <cmaser@gmx.de> - 1.3.0-2
- move cgis to libdir
- remove suse suppot (packages available at opensuse build system)
- add doxygen docs

* Wed Nov 03 2010 Michael Friedrich <michael.friedrich@univie.ac.at> - 1.3.0-1
- prepared 1.3.0, added log2ido for idoutils install

* Mon Oct 25 2010 Christoph Maser <cmaser@gmx.de> - 1.2.1-1
- update for release 1.2.1
- add build dep for httpd
- set INSTALL_OPTS_WEB=""

* Thu Sep 30 2010 Christoph Maser <cmaser@gmx.de> - 1.2.0-1
- update for release 1.2.0

* Mon Sep 20 2010 Michael Friedrich <michael.friedrich@univie.ac.at> - 1.0.3-4
- remove php depency for classic gui

* Wed Sep 01 2010 Christoph Maser <cmaser@gmx.de> - 1.0.3-3
- Put documentation in a separate package

* Tue Aug 31 2010 Christoph Maser <cmaser@gmx.de> - 1.0.3-2
- Set icinga-api logdir ownership to apache user 
- add php dependency for icinga-gui subpackage

* Wed Aug 18 2010 Christoph Maser <cmaser@gmx.de> - 1.0.3-1
- Update to 1.0.3-1

* Thu Jul 05 2010 Christoph Maser <cmaser@gmx.de> - 1.0.2-2
- Enable debuginfo

* Thu Jun 24 2010 Christoph Maser <cmaser@gmx.de> - 1.0.2-1
- Update to 1.0.2-1

* Wed Mar 03 2010 Christoph Maser <cmr@financial.com> - 1.0.1-1
- Update to 1.0.1-1

* Tue Dec 15 2009 Christoph Maser <cmr@financial.com> - 1.0-1
- Update to 1.0-1

* Mon Oct 26 2009 Christoph Maser <cmr@financial.com> - 1.0-0.RC1.2
- Split out icinga-api in sub package

* Mon Oct 26 2009 Christoph Maser <cmr@financial.com> - 1.0-0.RC1.1
- Update to 1.0-RC1
- Correct checkconfig --del in idoutils %preun

* Mon Oct 26 2009 Christoph Maser <cmr@financial.com> - 0.8.4-3
- Use icingacmd group and add apache user to that group instead
  of using apachegroup as icinga command group.

* Wed Oct 07 2009 Christoph Maser <cmr@financial.com> - 0.8.4-2
- make packages openSUSE compatible
- add %apachecondir, %apacheuser, %apachegroup depending on vendor
- configure add --with-httpd-conf=%{apacheconfdir} 
- configure add --with-init-dir=%{_initrddir}

* Wed Sep 16 2009 Christoph Maser <cmr@financial.com> - 0.8.4-1
- Update to version 0.8.4.

* Tue Sep 15 2009 Christoph Maser <cmr@financial.com> - 0.8.3-3
- Apply patch from 
  https://git.icinga.org/index?p=icinga-core.git;a=commit;h=8b3505883856310472979b152b9960f81cdbaad7

* Tue Sep 15 2009 Christoph Maser <cmr@financial.com> - 0.8.3-2
- Apply patch from 
  https://git.icinga.org/index?p=icinga-core.git;a=commit;h=068baf7bfc99a2a5a88b64d06df49d7395008b40

* Wed Sep 09 2009 Christoph Maser <cmr@financial.com> - 0.8.3-1
- Update to version 0.8.3.

* Thu Aug 27 2009 Christoph Maser <cmr@financial.com> - 0.8.2-3
- fix dir name ndoutils -> idoutils

* Thu Aug 27 2009 Christoph Maser <cmr@financial.com> - 0.8.2-2
- fix idututils post script
- copy database scripts from source to sysconfigdir

* Sat Aug 22 2009 Christoph Maser <cmr@financial.com> - 0.8.2-1
- Update to release 0.8.2.
- remove idoutils-init, init-script for ido2db is shipped now 

* Sun Jul 19 2009 Christoph Maser <cmr@financial.com> - 0.8.1-1
- initial package

